#' @export
#' @importFrom magrittr %>%
magrittr::`%>%`

#' @export
#' @importFrom tibble as_tibble
tibble::as_tibble

#' @export
#' @importFrom knitr knit_print
knitr::knit_print

#' @importFrom dplyr vars
#' @export
dplyr::vars

#' @importFrom tidyselect starts_with
#' @export
tidyselect::starts_with

#' @importFrom tidyselect ends_with
#' @export
tidyselect::ends_with

#' @importFrom tidyselect contains
#' @export
tidyselect::contains

#' @importFrom tidyselect matches
#' @export
tidyselect::matches

#' @importFrom tidyselect one_of
#' @export
tidyselect::one_of

#' @importFrom tidyselect everything
#' @export
tidyselect::everything

#' @importFrom tidyselect num_range
#' @export
tidyselect::num_range

#' @importFrom tidyselect last_col
#' @export
tidyselect::last_col
